import { useEffect, useState } from 'react';
import dayjs from 'dayjs';
import { View } from '@tarojs/components'
import { PowerScrollView } from '@antmjs/vantui';
import { useModel } from '@/store';
import { getBarcode } from '@/services/user';
import Item from './Item';

import './style.less'

export default (props) => {
  const { person } = useModel('userData')
  const [loading, setLoading] = useState(false)
  const [list, setList] = useState([
    { barcode: '32013201', sampledDt: '2022-05-15', reqStat: '0' },
    { barcode: '32013202', sampledDt: '2022-05-15', reqStat: '6' },
    { barcode: '32013203', sampledDt: '2022-05-15', reqStat: '6' },
    { barcode: '32013204', sampledDt: '2022-05-15', reqStat: '6' },
    { barcode: '32013205', sampledDt: '2022-05-15', reqStat: '6' },
    { barcode: '32013206', sampledDt: '2022-05-15', reqStat: '6' },
  ])

  useEffect(() => {
    if (person && person.personId) {
      const today = dayjs()
      const params = {
        startDate: today.subtract(7, 'day').format('YYYY-MM-DD'),
        endDate: today.format('YYYY-MM-DD'),
        idNo: person.idNo,
      }
      setLoading(true)
      getBarcode(person.personId, params).then((res) => {
        setList(res || [])
        setLoading(false)
      }).catch(err => {
        console.error(err)
        setLoading(false)
      })
    }
  }, [person])

  return (
    <PowerScrollView
      className='barcode-history-list'
      refresherEnabled={false}
      total={list.length}
    >
      {
        list.map((barData, inx) => (
          <Item key={inx} person={person} barData={barData} />
        ))
      }
    </PowerScrollView>
  )
}
